#######################################################################
# File Name    : proj_constraints.tcl
# Date Created : 12/06/99 
# Author       : Tim L Wilson, Gregg D. Lahti & Rodney Pesavento
# Project      : TOPS Example Code for SNUG
#######################################################################
# $Id$
#######################################################################
# Description: Set up project specific constraints
#######################################################################

#####################################################################
# Customize the defaults here
#####################################################################
# Default unit-to-unit I/O delays, and which clock they reference
set G_DEFAULT_INPUT_DELAY [expr .750 * $G_NS];
set G_DEFAULT_OUTPUT_DELAY [expr .750 * $G_NS];

# Default cell loading output ports
set G_DEFAULT_LOAD [load_of [file join $G_LIBRARY_NAME $G_DEFAULT_LOAD_CELL $G_DEFAULT_LOAD_CELL_PIN]];
set G_DEFAULT_LOAD [expr 10 * $G_DEFAULT_LOAD];

#####################################################################
# The following variables are included as possible constraints that 
# may be set by the project. Uncomment the commands below.
#####################################################################
# Set max area, Synopsys recommends setting close to expected area (NOT 0)
#set G_DEFAULT_MAXAREA 0;

# Set max fanout (allow library to constrain)
#set G_DEFAULT_MAX_FANOUT 16;

#####################################################################
# Set critical range so that more than  just the critical path gets
# optimized.  The compile commmand only works on the path with the
# greatest negative slack, so this command makes compile work on
# more paths.
#####################################################################
#set G_DEFAULT_CRITICAL_RANGE 0.0;

#####################################################################
# You shouldn't have to edit the rest of this file if you set the
# variables above and the simplistic case is all you need
#####################################################################
echo "";
echo "#CONSTRAINTS: DEFAULT CONSTRAINTS";
echo "#CONSTRAINTS: --------------------";
echo "#CONSTRAINTS: DRIVING_CELLPIN -> " $G_DEFAULT_DRIVING_CELL\/$G_DEFAULT_DRIVING_CELL_PIN;
echo "#CONSTRAINTS: LOAD            -> " $G_DEFAULT_LOAD;
#echo "#CONSTRAINTS: AREA            -> " $G_DEFAULT_MAXAREA;
#echo "#CONSTRAINTS: CRITICAL_RANGE  -> " $G_DEFAULT_CRITICAL_RANGE;
#echo "#CONSTRAINTS: FANOUT          -> " $G_DEFAULT_MAX_FANOUT;
echo "";

###################################################################
# Set max_area, critical range, fanout, fix joined ports
###################################################################
#set_max_area $G_DEFAULT_MAXAREA;
#set_critical_range $G_DEFAULT_CRITICAL_RANGE $G_DESIGN_NAME;
#set_max_fanout $G_DEFAULT_MAX_FANOUT $G_DESIGN_NAME;

# Variable used to cleanup verilog assign statements
set_fix_multiple_port_nets -all;

###################################################################
# Create a list of all inputs that are not clock pins 
###################################################################
set clk_ports [get_ports -filter {@is_clock == true} "*"];
set rst_ports [get_ports -filter {@is_reset == true} "*"];

set in_list [remove_from_collection \
            [get_ports -filter {@port_direction == in} "*"] \
            [concat $clk_ports $rst_ports]];

set out_list [all_outputs];

###################################################################
# Set default input and output delays
###################################################################
if {[info exists G_DEFAULT_CLOCK]} {
  echo "#CONSTRAINTS: setting default delay with respect to $G_DEFAULT_CLOCK";
  set_output_delay $G_DEFAULT_OUTPUT_DELAY -clock $G_DEFAULT_CLOCK $out_list;
  set_input_delay $G_DEFAULT_INPUT_DELAY -clock $G_DEFAULT_CLOCK $in_list;
}

###################################################################
# Set default driving cell for input pins
###################################################################
set_driving_cell \
   -cell $G_DEFAULT_DRIVING_CELL \
   -pin $G_DEFAULT_DRIVING_CELL_PIN \
   -library $G_LIBRARY_NAME $in_list;

###################################################################
# Set default load on all outputs
###################################################################
set_load $G_DEFAULT_LOAD [all_outputs];

###################################################################
# Clean up local variables
###################################################################
unset in_list;
unset out_list;
unset G_DEFAULT_INPUT_DELAY;
unset G_DEFAULT_OUTPUT_DELAY;
unset G_DEFAULT_LOAD;

#####################################################################
# $Log$
#####################################################################



