#######################################################################
# File Name    : proj_dc_setup.tcl
# Date Created : 03/09/2000
# Author       : Tim L Wilson, Gregg D. Lahti & Rodney Pesavento
# Project      : TOPS Example Code for SNUG
#######################################################################
# $Id$
#######################################################################
# Description: This file is sourced from the USER's .synopsys_dc.setup
#######################################################################

###########################################################################
# Get environment variables from project environment setup script 
###########################################################################
set G_PROJ_SYN [getenv PROJ_SYN]; # global synthesis dir
set G_PROJ_LIB [getenv PROJ_LIB]; # global library dir
set G_PROJ_DBS [file join ${G_PROJ_LIB} dbs]; # global library dbs dir, contains all gate/io libs

echo "#SETUP: Sourcing Project Synopsys setup file ($G_PROJ_SYN/proj_dc_setup.tcl)";

###########################################################################
# Set Company & Designer (author)
###########################################################################
set company "TOPS";
set designer [getenv USER];

###########################################################################
# DC/BC Message output variables 
###########################################################################
set verbose_messages false;

###########################################################################
# Create variables from unix environment variables & 
# Define subdirectories of the unit's synthesis area
###########################################################################
# The following var G_SYN_PATH can be hardcoded to "."
set G_SYN_PATH "."; # PROJECT Edit, unit synthesis dir

# Edit paths to match project directory structure
set G_SRC_PATH [file join .. src];
set G_LOG_PATH [file join ${G_SYN_PATH} log];
set G_OUTPUTS_PATH [file join ${G_SYN_PATH} outputs];
set G_REPORTS_PATH [file join ${G_SYN_PATH} reports];
set G_SCRIPTS_PATH [file join ${G_SYN_PATH} scripts];
set G_WORKLIB_PATH [file join ${G_SYN_PATH} worklib];
set G_DBS_PATH [file join ${G_SYN_PATH} dbs];

###########################################################################
# Enable source command to use search path:
###########################################################################
set sh_source_uses_search_path true;
set sh_source_logging true;
set sh_returns_process_status true;

###########################################################################
# Setup Synopsys search path
# G_DBS_PATH is not included since synopsys will automatically search path
# for db's to link which is not always the desired case.
###########################################################################
# Set the default search path from $SYNOPSYS admin setup file
set searchline1 [file join ${synopsys_root}  libraries syn]
set searchline2 [file join ${synopsys_root} dw sim_ver]
set search_path [list . $searchline1 $searchline2];
set search_path "$search_path $G_PROJ_DBS $G_PROJ_SYN $G_SRC_PATH $G_SCRIPTS_PATH"; 

define_design_lib work -path $G_WORKLIB_PATH;

###########################################################################
# Setup Synthetic Libraries 
###########################################################################
set synthetic_library [list dw01.sldb dw02.sldb dw03.sldb dw04.sldb dw05.sldb dw07.sldb];

###########################################################################
# $TOPS is a global array use to pass a set of vars to a proc
# Note: each elem need not be set yet, this is project/machine specific
###########################################################################
global G_TOPS;
set G_TOPS(NULL) {/dev/null};        # add elem NULL to global array
set G_TOPS(TMP) {/tmp/TOPS};        # add elem TMP to global array

###########################################################################
# Project log file names and paths
###########################################################################
set command_log_file [file join ${G_LOG_PATH} command.log];
set exit_delete_command_log_file false;
set view_command_log_file [file join ${G_LOG_PATH} view_command.log];
set filename_log_file [file join ${G_LOG_PATH} filenames.log];
set exit_delete_filename_log_file false;

###########################################################################
# Setup the project Cache Root Directory          
###########################################################################
# Assumes the synopsys_cache has been setup in the ${G_PROJ_LIB}
set myline1 [file join ${synopsys_root} libraries syn]  
set myline2 [file join ${G_PROJ_LIB} synopsys_cache]
set cache_read "$myline1 $myline2";
set cache_write [file join ${G_PROJ_LIB} synopsys_cache];
set cache_read_info true;
set cache_write_info true;
set cache_file_chmod_octal 777;
set cache_dir_chmod_octal 777;

###########################################################################
# If desired, USER may Suppress some warning messages:
###########################################################################
# use suppress_message instead of set suppress_errors
# since elaborate changes the suppress_errors var
suppress_message {UI-31 UID-401 NMA-16 SYNOPT-8 SYNOPT-9 SYNOPT-18 \
                  CMD-030 CMD-041 EQN-10 VHDL-2097 SYNH-3 DDB-74};

###########################################################################
# Warn about dotfiles that may cause path problems, etc.
# Recommend NOT having local synopsys setup files, allows too much variability.
###########################################################################
if {[file exists [file join . .synopsys_dc.setup]]} {
   echo "#SETUP: WARNING .synopsys_dc.setup found in working directory";
   echo "#SETUP:          This could cause problems...";
}

###########################################################################
# Source TOPS global procedures file
###########################################################################
source [file join ${G_PROJ_SYN} util_procs.tcl];

###########################################################################
# DC variable settings needed project-wide
###########################################################################
# Put limits on special licenses 
set synlib_disable_limited_licenses true;
set hdl_keep_licenses false;
set hdlin_enable_vpp true;
set hdlin_ff_always_async_set_reset true
set hdlin_translate_off_skip_text true;
set hdlout_internal_busses true;

###########################################################################
# Set bus naming variables
###########################################################################
set bus_inference_style {%s[%d]};
set bus_naming_style {%s[%d]};
set bus_range_separator_style {:};

##########################################################################
# Incorrect verilog written if change_names_dont_change_bus_members = false 
##########################################################################
set change_names_dont_change_bus_members true;

###########################################################################
# Changes a sub designs name based on parameters passed to it.
###########################################################################
set template_naming_style "%s_%p";
set template_separator_style "_";
set template_parameter_style "%d";

###########################################################################
# Set VERILOGOUT Variables
###########################################################################
set verilogout_no_tri true;
set verilogout_single_bit false;
set verilogout_levelize false;
set verilogout_higher_designs_first true;
set verilogout_show_unconnected_pins true;
  
###########################################################################
# Set the history command to "keep" 100 instead of default 20
###########################################################################
history keep 100;

###########################################################################
# Define any project-specific aliases here. These are provided for
# interactive mode ONLY! Never recommended for scripts.
###########################################################################
alias h "history";
alias so "source";
alias cdn "current_design";

echo "#SETUP: Completed sourcing Project Synopsys setup";
echo "";

###########################################################################
# $Log$
###########################################################################



