#######################################################################
# File Name    : proj_library.tcl
# Date Created : 3/09/2000
# Author       : Tim L. Wilson, Gregg D. Lahti & Rodney Pesavento
# Project      : TOPS Example Code for SNUG
#######################################################################
# $Id$
#######################################################################
# Description: Set up library path/variable for library
#######################################################################

# Trap to check if G_LIBRARY_NAME is not set (USER invocation)
if {[info exists G_LIBRARY_NAME] == 0} {
  # Set to null & allow default loop below to set
  set G_LIBRARY_NAME "DEFAULT";
}

# If not set by synbatch or syn_make.rules, set to project default
if {$G_LIBRARY_NAME == "DEFAULT"} {
  # Set the default, this is the only place lib vars need to be set
  set G_LIBRARY_NAME lsi_10k; # PROJECT Specific Edit
}

# Source the files required for the synthesis target library    
switch -exact -- $G_LIBRARY_NAME {
  altera {
    echo "#LIBRARY: ERROR: altera not setup yet!\n";
  }

  lsi_10k {
    echo "#LIBRARY: Setting up $G_LIBRARY_NAME library files & variables";
    #######################################################################
    # Load project library setup script
    #######################################################################
    # Set multiplier, library is in picoseconds
    set G_NS 1;    

    # These variables CAN modify default library values
    #set G_MAX_TRANSITION [expr 2.0 * $G_NS];
    #set G_MAX_CAPACITANCE 5.0;
    #set G_MAX_DELAY 5.0;

    # EDIT HERE with the Synopsys library variables
    # Default Scan Flop used for drive
    set G_DEFAULT_DRIVING_CELL {FD1S};
    set G_DEFAULT_DRIVING_CELL_PIN {Q};

    # Default nand used for load
    set G_DEFAULT_LOAD_CELL {ND2};
    set G_DEFAULT_LOAD_CELL_PIN {A};

    # This variable is used to normalize to "NAND equivalent gates"
    set G_DEFAULT_NAND_CELL {ND2};
    
    # Set Operating conditions & min/max libraries for synthesis  	
    set G_MAX_LIBRARY ${G_LIBRARY_NAME};
    set G_MIN_LIBRARY ${G_LIBRARY_NAME};
    set G_MAX_OP_CONDITION {WCCOM};
    set G_MIN_OP_CONDITION {BCCOM};
    
    # Setup wireload variables
    set G_DEFAULT_WIRE_LOAD {90x90};
    set G_CWLM_LIBRARY [list ""];
    set auto_wire_load_selection false;
    
    #######################################################################
    # Set library name and search path
    #######################################################################
    ## NOTE: Assumes dbs path already set in search_path from proj_dc_setup.tcl
    
    #######################################################################
    # Define Synthesis Libraries 
    #######################################################################
    # Set the target library, include RAM and other special cell libs
    set target_library [list ${G_MAX_LIBRARY}.db];
    set symbol_library [list lsi_10k.sdb];

    # Synthetic_library is assigned in proj_dc_setup.scr, include * for designs in memory
    set link_library "* $target_library $synthetic_library";
    
    # Read all the libraries into memory
    foreach lib [concat $target_library ${G_MIN_LIBRARY}.db] {
      read_db $lib;
    }; # end of foreach

    #######################################################################
    # Create default don't use list, if not PT shell session.
    # Recommend using the G_PROJ_DONT_USE variable to set the attribute.
    # This allows the USER to remove the attribute:
    # dc_shell-t> remove_attribute $G_PROJ_DONT_USE dont_use
    #######################################################################
    if {[set synopsys_program_name] != "pt_shell"} {
      # Not using JK flops
      set G_PROJ_DONT_USE "${G_LIBRARY_NAME}/FJK*";

      # Not using latch components
      set G_PROJ_DONT_USE [concat $G_PROJ_DONT_USE "${G_LIBRARY_NAME}/LD*"];
      set G_PROJ_DONT_USE [concat $G_PROJ_DONT_USE "${G_LIBRARY_NAME}/LS*"];

      # Set dont_use attribute on cells in list
      set_dont_use $G_PROJ_DONT_USE;
    }; # end if
  }

  default {
    echo "#LIBRARY: Error, G_LIBRARY_NAME variable set incorrectly";
    echo "#LIBRARY: G_LIBRARY_NAME = $G_LIBRARY_NAME\n";
  }
  
}; # end switch

# Set dont_use attribute on the slow design_ware components (speeds compilation)
if {[set synopsys_program_name] != "pt_shell"} {
  read_db standard.sldb;
  set_dont_use {standard.sldb/DW02_mult/csa \
                standard.sldb/DW01_add/rpl \
                standard.sldb/DW01_add/cla \
                standard.sldb/DW01_sub/rpl \
                standard.sldb/DW01_sub/cla \
                standard.sldb/DW01_addsub/rpl \
                standard.sldb/DW01_addsub/cla \
                standard.sldb/DW01_inc/rpl \
                standard.sldb/DW01_inc/cla \
                standard.sldb/DW01_dec/rpl \
                standard.sldb/DW01_dec/cla \
                standard.sldb/DW01_incdec/rpl \
                standard.sldb/DW01_incdec/cla \
                };
}; # end if
  
#######################################################################
# $Log$
#######################################################################



