#######################################################################
# File Name    : proj_pt_setup.tcl
# Date Created : 03/09/2000
# Author       : Tim L Wilson
# Project      : TOPS Example Code for SNUG
#######################################################################
# $Id$
#######################################################################
# Description: This file is sourced from the USER's .synopsys_dc.setup
#######################################################################

###########################################################################
# Suppress some warnings:
###########################################################################
# use suppress_message instead of 
# set suppress_errors (elaborate chgs this var)
suppress_message {CMD-041 CMD-030}

###########################################################################
# Get environment variables from project environment setup script 
###########################################################################
set G_PROJ_SYN [getenv PROJ_SYN]; # global synthesis dir
set G_PROJ_LIB [getenv PROJ_LIB]; # global library dir
set G_PROJ_DBS [file join ${G_PROJ_LIB} dbs]; # global library dbs dir, contains all gate/io libs

echo "#SETUP: Sourcing Project Synopsys PT setup file ($G_PROJ_SYN/proj_pt_setup.tcl)";

###########################################################################
# Set Company & Designer (author)
###########################################################################
set company "TOPS";
set designer [getenv USER];

###########################################################################
# Create variables from unix environment variables & 
# Define subdirectories of the unit's synthesis area
###########################################################################
# The following var G_SYN_PATH can be hardcoded to "."
set G_SYN_PATH "."; # PROJECT Edit, unit synthesis dir

# Edit paths to match project directory structure
set G_LOG_PATH [file join ${G_SYN_PATH} log];
set G_OUTPUTS_PATH [file join ${G_SYN_PATH} outputs];
set G_REPORTS_PATH [file join ${G_SYN_PATH} reports];
set G_SCRIPTS_PATH [file join ${G_SYN_PATH} scripts];
set G_DBS_PATH [file join ${G_SYN_PATH} dbs];

###########################################################################
# Enable source command to use search path:
###########################################################################
set sh_source_uses_search_path true;

###########################################################################
# Setup Synopsys search path
# G_DBS_PATH is not included since synopsys will automatically search path
# for db's to link which is not always the desired case.
###########################################################################
set search_path [list . [file join ${synopsys_root} libraries syn] \
                        [file join ${synopsys_root} dw sim_ver]];
set search_path "$search_path $G_PROJ_DBS $G_PROJ_SYN $G_SCRIPTS_PATH"; 

###########################################################################
# $TOPS is a global array use to pass a set of vars to a proc
# Note: each elem need not be set yet
###########################################################################
global G_TOPS;
set G_TOPS(NULL) {/dev/null};         # add elem NULL to global array
set G_TOPS(TMP)  {/tmp/TOPS};        # add elem TMP to global array

###########################################################################
# Project log file names and paths
###########################################################################
set command_log_file [file join ${G_LOG_PATH} command.log];
set exit_delete_command_log_file false;
set view_command_log_file [file join ${G_LOG_PATH} view_command.log];
set filename_log_file [file join ${G_LOG_PATH} filenames.log];
set exit_delete_filename_log_file false;

###########################################################################
# Setup Synthetic Libraries 
###########################################################################
# Set because link_library will require this being set (proj_library.tcl)
set synthetic_library "";

###########################################################################
# Warn about dotfiles that may cause path problems, etc.
# Recommend NOT having local synopsys setup files, allows too much variability.
###########################################################################
if {[file exists [file join . .synopsys_pt.setup]]} {
   echo "#SETUP: WARNING .synopsys_pt.setup found in working directory";
   echo "#SETUP:          This could cause problems...";
}

###########################################################################
# Source TOPS global procedures file
###########################################################################
source [file join ${G_PROJ_SYN} util_procs.tcl];

###########################################################
# Set the history command to "keep" 100 instead of default 20
###########################################################
history keep 100;

###########################################################################
# Define any project-specific aliases here
###########################################################################
alias h "history";
alias so "source";

echo "#SETUP: Completed sourcing Project Synopsys setup";
echo "";

###########################################################################
# $Log$
###########################################################################



