#######################################################################
# File Name    : util_reports.tcl
# Date Created : 12/01/99
# Author       : Tim L. Wilson, Gregg D. Lahti & Rodney Pesavento
# Project      : TOPS Example Code for SNUG
#######################################################################
# $Id$
#######################################################################
# Description:  Contains the TOPS general reporting procedures.
#######################################################################

#######################################################################
# Report area
#######################################################################
proc P_report_area {rpath dn} {
  set output_file [file join $rpath ${dn}_area.rpt];
  echo "#REPORTS: report_area: in $output_file";
  redirect $output_file {report_area -nosplit};
  unset output_file;
}; # end P_report_area

#######################################################################
# check_design
#######################################################################
proc P_report_check_design {rpath dn} {
  set output_file [file join $rpath ${dn}_check_design.rpt];
  echo "#REPORTS: check_design: in $output_file";
  redirect $output_file {[check_design]};
  unset output_file;
}; # end P_report_check_design

#######################################################################
# Do a check_design, *but* ungroup -all first
#######################################################################
proc P_report_check_design_ungroup {rpath dn} {
  global G_TOPS;
  set output_file [file join $rpath ${dn}_design_ungroup.rpt];
  echo "#REPORTS: check_design ungroup: in $output_file";

  ##set tmpfile [file join $G_TOPS(TMP) ${dn}${timestamp}];
  set tmpfile ${dn}[eval pid][clock seconds].tmp

  echo "#REPORTS: check_design ungroup: saving db before ungroup";
  write -f db -hier -o $tmpfile;
  echo "#REPORTS: check_design ungroup: ungrouping design";
  ungroup -all;
  redirect $output_file {check_design};

  remove_design -designs;
  echo "#REPORTS: check_design ungroup: re-reading original design";
  read_file -f db $tmpfile;

  current_design $dn;

  redirect $G_TOPS(NULL) {exec grm -f $tmpfile};
  unset output_file;
}; # end P_report_check_design_ungroup

#######################################################################
# Do a check_timing
#######################################################################
proc P_report_check_timing {rpath dn} {
  set output_file [file join $rpath ${dn}_check_timing.rpt];
  echo "#REPORTS: check_timing: in $output_file";
  redirect $output_file {check_timing};
  unset output_file;
}; # end P_report_check_timing

#######################################################################
# Do a check_test
#######################################################################
proc P_report_check_test {rpath dn} {
  set output_file [file join $rpath ${dn}_check_test.rpt];
  echo "#REPORTS: check_test: in $output_file";
  redirect $output_file {check_test};
  unset output_file;
}; # end P_report_check_test

#######################################################################
# Report clocks
#######################################################################
proc P_report_clock {rpath dn} {
  set output_file [file join ${rpath} ${dn}_report_clock.rpt];
  echo "#REPORTS: report_clock & -skew: $output_file";
  redirect $output_file {report_clock -nosplit};
  redirect -append $output_file {report_clock -skew -nosplit};
  redirect -append $output_file {report_timing_requirements -to [all_clocks]};
  redirect -append $output_file {report_clock -attributes -nosplit};
  unset output_file;
}; # end P_report_clock

#######################################################################
# Report compile options
#######################################################################
proc P_report_compile_options {rpath dn} {
  set output_file [file join $rpath ${dn}_compile_options.rpt];
  echo "#REPORTS: compile_options: in $output_file";
  redirect $output_file {report_compile_options -nosplit};
  unset output_file;
}; # end P_report_compile_options

#######################################################################
# Report design
#######################################################################
proc P_report_design {rpath dn} {
  set output_file [file join $rpath ${dn}_design.rpt];
  echo "#REPORTS: report design: in $output_file";
  redirect $output_file {report_design -nosplit};
  unset output_file;
}; # end P_report_design

#######################################################################
# Report library cells that have dont_use attribute
#######################################################################
proc P_report_dont_use_cells {rpath dn} {
  global G_LIBRARY_NAME;
  set output_file [file join $rpath ${dn}_${G_LIBRARY_NAME}_dont_use_cell.rpt];
  echo "#REPORTS: Generating file of cells with dont_use attribute set";

  # Create list of cells
  set cell_list [filter [find cell $G_LIBRARY_NAME/*] "@dont_use == true"];
  redirect $output_file {echo "Library cells with dont_use attribute set"};
  foreach_in_collection cell_elem $cell_list {
    # Echo cells to file
    redirect -append $output_file {echo [get_object_name $cell_elem]};
  }
  unset output_file;
}; # end P_report_dont_use_cells

#######################################################################
# Report ignored timing constraints
#######################################################################
proc P_report_ignored {rpath dn} {
  set output_file [file join $rpath ${dn}_ignored.rpt];
  echo "#REPORTS: report ignored: in $output_file";
  redirect $output_file {report_timing_requirements -ignored -nosplit};
  unset output_file;
}; # end P_report_ignored

#######################################################################
# Report timing constraints
#######################################################################
proc P_report_timing_requirements {rpath dn} {
  set output_file [file join $rpath ${dn}_timing_req.rpt];
  echo "#REPORTS: report timing requirements: in $output_file";
  redirect $output_file {report_timing_requirements -nosplit};
  unset output_file;
}; # end P_report_timing_requirements

#######################################################################
# Report all endpoint margins
#######################################################################
proc P_report_endpoints {rpath dn} {
  set output_file [file join $rpath ${dn}_endpoints.rpt];
  echo "#REPORTS: report endpoints: in $output_file";
  redirect $output_file {report_timing -path end -nosplit};
  unset output_file;
}; # end P_report_endpoints

#######################################################################
# Total nets / pins per net report
#######################################################################
proc P_report_pins_per_net {rpath dn} {
  set output_file [file join $rpath ${dn}_pins_per_net.rpt];
  echo "#REPORTS: pins_per_net: in $output_file";
  redirect $output_file {report_net -nosplit};
  unset output_file;
}; # end P_report_pins_per_net

#######################################################################
# Report ports
#######################################################################
proc P_report_port {rpath dn} {
  set output_file [file join $rpath ${dn}_port.rpt];
  echo "#REPORTS: report_port: in $output_file";
  redirect $output_file {report_port -verbose -nosplit};
  unset output_file;
}; # end P_report_port

#######################################################################
# Report resources
#######################################################################
proc P_report_reference {rpath dn} {
  global G_TOPS;
  set output_file [file join $rpath ${dn}_reference.rpt];
  echo "#REPORTS: report_reference: $output_file";
  redirect $output_file {report_reference -nosplit};
  unset output_file;
}; # end P_report_reference

#######################################################################
# Report resources, but ungroup -all first
#######################################################################
proc P_report_reference_ungroup {rpath dn} {
  global G_TOPS;

  set output_file [file join $rpath ${dn}_reference_ungroup.rpt];
  set tmpfile ${dn}[eval pid][clock seconds].tmp

  echo "#REPORTS: report_reference ungroup: in $output_file";
  write -f db -hier -o $tmpfile;
  echo "#REPORTS: report_reference ungroup: ungrouping design";
  ungroup -flatten -all;
  echo "#REPORTS: report_reference ungroup: doing report_reference";
  redirect $output_file {report_reference -nosplit};

  remove_design -designs;
  echo "#REPORTS: report_reference ungroup: re-reading original design";
  read_file -f db $tmpfile;
  current_design $dn;

  redirect $G_TOPS(NULL) {exec grm -f $tmpfile};

  unset output_file;
  unset tmpfile;
}; # end P_report_reference_ungroup

#######################################################################
# Report test
#######################################################################
proc P_report_test {rpath dn} {
  set output_file [file join $rpath ${dn}_report_test.rpt];
  echo "#REPORTS: report scan insertion: in $output_file";
  redirect $output_file {report_test -configuration -port -scan_path -nosplit};
  unset output_file;
}; # end P_report_test

#######################################################################
# Script to detect unmapped parts
#######################################################################
proc P_report_unmapped {rpath dn} {
  global G_TOPS;

  set output_file [file join $rpath ${dn}_unmapped.rpt];
  echo "#REPORTS: report unmapped: in $output_file";
  echo "#REPORTS: report unmapped: checking for unmapped components";
  redirect $G_TOPS(NULL) \
    {set gtech_cells [get_cells * -hier -filter "@is_unmapped==true"]};

  if { $gtech_cells != {} } {
    echo "#REPORTS: report unmapped: design has unmapped cells (ERROR)";
    redirect $output_file {report_cell -nosplit $gtech_cells};
  } else {
    echo "#REPORTS: report unmapped: there are no unmapped cells in the design";
    redirect $output_file \
      {echo "#REPORTS: unmapped: there are no unmapped cells in the design"};
  }
  unset gtech_cells;
  unset output_file;
}; # end P_report_unmapped

#######################################################################
# Report constraints
#######################################################################
proc P_report_vio {rpath dn} {
  set output_file [file join $rpath ${dn}_all_violators.rpt];
  echo "#REPORTS: all_violators: in $output_file";
  redirect $output_file {[report_constraint -all_violators -nosplit]};
  unset output_file;
}; # end P_report_vio

#######################################################################
# Report all max cap violations
#######################################################################
proc P_report_vio_max_cap {rpath dn} {
  set output_file [file join $rpath ${dn}_vio_max_cap.rpt];
  echo "#REPORTS: all_violators max_cap: in $output_file";
  redirect $output_file {report_constraint -all_violators -max_cap};
  unset output_file;
}; # end P_report_vio_max_cap

#######################################################################
# Report all max delay violations
#######################################################################
proc P_report_vio_max_delay {rpath dn} {
  set output_file [file join $rpath ${dn}_vio_max_delay.rpt];
  echo "#REPORTS: all_violators max_delay: in $output_file";
  redirect $output_file {report_constraint -all_violators -max_delay -verbose};
  unset output_file;
}; # end P_report_vio_max_delay

#######################################################################
# Report all min delay violations
#######################################################################
proc P_report_vio_min_delay {rpath dn} {
  set output_file [file join $rpath ${dn}_vio_min_delay.rpt];
  echo "#REPORTS: all_violators min_delay: in $output_file";
  redirect $output_file {report_constraint -all_violators -min_delay -verbose};
  unset output_file;
}; # end P_report_vio_min_delay

#######################################################################
# Inputs to Registers
#######################################################################
proc P_report_ins2flops {rpath dn} {
  set output_file [file join $rpath ${dn}_ins2flops.rpt];
  echo "#PROJ_REPORTS: report_ins2flops: in $output_file";

  set in_list [remove_from_collection \
              [get_ports -filter {@port_direction == in} "*"] \
              [get_ports -filter {@is_clock == true} "*"]];

  redirect $output_file {echo ""};

  foreach inpin $in_list {
    redirect -append $output_file {report_timing -path short -from $inpin \
      -to [all_registers] -nets -trans -max_paths 5 -nosplit};
  }

  unset inpin;
  unset in_list;
  unset output_file;
}; # end P_report_ins2flops

#######################################################################
# Registers to Outputs
#######################################################################
proc P_report_flops2outs {rpath dn} {
  set output_file [file join $rpath ${dn}_flops2outs.rpt];
  echo "#PROJ_REPORTS: report_flops2outs: in $output_file";

  redirect $output_file {echo ""};

  foreach outpin [all_outputs] {
    redirect -append $output_file {report_timing -path short \
      -from [all_registers -clock_pins] -to $outpin -nets -trans -nosplit};
  }

  unset outpin;
  unset output_file;
}; # end P_report_flops2outs

#######################################################################
# Inputs to Outputs
#######################################################################
proc P_report_ins2outs {rpath dn} {
  set output_file [file join $rpath ${dn}_ins2outs.rpt];
  echo "#PROJ_REPORTS: report_ins2outs: in $output_file";

  set in_list [remove_from_collection \
              [get_ports -filter {@port_direction == in} "*"] \
              [get_ports -filter {@is_clock == true} "*"]];

  redirect $output_file {report_timing -path short -from $in_list \
    -to [all_outputs] -nets -trans -max_paths 5 -nosplit};

  unset in_list;
  unset output_file;
}; # end P_report_ins2outs

#######################################################################
# Report number of Registers & Latches
#######################################################################
proc P_report_flop_latch {rpath dn} {
  set output_file [file join $rpath ${dn}_flop_latch.rpt];
  echo "#PROJ_REPORTS: report_flop_latch: in $output_file";

  set flop_cnt [sizeof_collection [all_registers -edge_triggered]];
  set latch_cnt [sizeof_collection [all_registers -level_sensitive]];

  redirect $output_file {echo "Total number of flops in $dn = $flop_cnt"};
  redirect -append $output_file \
    {echo "Total number of latches in $dn = $latch_cnt"};

  unset output_file;
}; # end P_report_flop_latch

#######################################################################
# Report timing requirements
#######################################################################
proc P_report_timing_requirements {rpath dn} {
  set output_file [file join $rpath ${dn}_timing_requirements.rpt];
  echo "#PROJ_REPORTS: report_timing_requirements: in $output_file";

  redirect $output_file {report_timing_requirements -to [all_clocks]};

  unset output_file;
}; # end P_report_timing_requirements

#######################################################################
# $Log$
#######################################################################



