#!/bin/csh -fx
###############################################################################
# Script name  : tops_setup
# Date created : 12/12/99
# Author       : 
# Project      : TOPS Example Code for SNUG
###############################################################################
# $Id$
###############################################################################
# Description : Setup script for TOPS (source this file)
###############################################################################

###############################################################################
# Setup project default environment variables
###############################################################################
# EDIT HERE with your environment paths
set proj = "ADD-PROJECT-NAME-HERE"
setenv PROJ_ROOT "ADD-YOUR-ROOT-LEVEL-DIRECTORY-HERE"
setenv PROJ_LIB $PROJ_ROOT/lib
setenv PROJ_SYN $PROJ_ROOT/tools/syn 
setenv PROJ_NAME ${proj} 
umask 002 

###############################################################################
# Setup script info/error warning items
###############################################################################

echo ""
echo "***************************  Starting TOPS Setup *************************"
 
###############################################################################
# Set up Project Default Tool Versions
###############################################################################
set syn_version = 2000.05

##############################################################################
# Set Up basic Unix tools and environment
###############################################################################

# Added tools/syn to path to include the TOPS synthesis scripts
set path = ($PROJ_ROOT/tools/syn $path)

##############################################################################
# Set up Synopsys 
##############################################################################
# EDIT HERE with the Synopsys setup
echo "Setting up SYNOPSYS TOOLS"

# check the USER Synopsys DC setup file
diff ${PROJ_SYN}/home.synopsys_dc.setup_tcl ~/.synopsys_dc.setup > & /dev/null
# NOTE: YOU MUST IMMEDIATELY CHECK THE STATUS VAR TO SEE THE DIFF RESULTS!!
####################################################################
# Check the status and modify ~/.synopsys_dc.setup as needed
####################################################################
switch($status)
  # the project template and the USER setup compare
  case 0 :
    echo " USER Synopsys DC setup file verified"
    breaksw
  # the project template and the USER setup miscompare
  case 1 :
    set date_var = `date "+%m%d%y"`
    echo " USER Synopsys DC setup file does not compare to the template"
    echo " Moved USER Synopsys DC setup to ~/.synopsys_dc.setup_$date_var"
    mv ~/.synopsys_dc.setup ~/.synopsys_dc.setup_${date_var}
    cp ${PROJ_SYN}/home.synopsys_dc.setup_tcl ~/.synopsys_dc.setup
    breaksw
  # the USER setup file does not exist, copy template
  case 2 :
    echo " USER synopsys DC setup copied from template"
    cp ${PROJ_SYN}/home.synopsys_dc.setup_tcl ~/.synopsys_dc.setup
    breaksw
  # something is wrong
  default:
    echo "ERROR: Synopsys DC setup not complete"
    breaksw
endsw

####################################################################
# check the USER Synopsys PT setup file
####################################################################
diff ${PROJ_SYN}/home.synopsys_pt.setup_tcl ~/.synopsys_pt.setup > & /dev/null
# NOTE: YOU MUST IMMEDIATELY CHECK THE STATUS VAR TO SEE THE DIFF RESULTS!!
# Check the status and modify ~/.synopsys_pt.setup as needed
switch($status)
  # the project template and the USER setup compare
  case 0 :
    echo " USER Synopsys PT setup file verified"
    breaksw
  # the project template and the USER setup miscompare
  case 1 :
    set date_var = `date "+%m%d%y"`
    echo " USER Synopsys PT setup file does not compare to the template"
    echo " Moved USER Synopsys PT setup to ~/.synopsys_pt.setup_$date_var"
    mv ~/.synopsys_pt.setup ~/.synopsys_pt.setup_${date_var}
    cp ${PROJ_SYN}/home.synopsys_pt.setup_tcl ~/.synopsys_pt.setup
    breaksw
  # the USER setup file does not exist, copy template
  case 2 :
    echo " USER synopsys setup copied from template"
    cp ${PROJ_SYN}/home.synopsys_pt.setup_tcl ~/.synopsys_pt.setup
    breaksw
  # something is wrong
  default:
    echo "ERROR: Synopsys PT setup not complete"
    breaksw
endsw

##############################################################################
# Done with script
##############################################################################

echo "****************************  End TOPS Setup *****************************"

##############################################################################
# $Log$
##############################################################################

