/**********************************************************************/
// File Name         : lfsr.v
// Date Created      : 05/18/00
// Author            : 
// Project           : unknown 
/**********************************************************************/
// $Id: newunit.v,v 1.1 2000/02/08 23:05:20 glahti Exp $
/**********************************************************************/
// Description :
//   This module implements an LFSR (linear-feedback-shift register.
//   This is a 16-tap, maximal length LFSR implementation.
/**********************************************************************/

`define DELTA 1

module lfsr (clk,
             rst_n,
             capture,
             lfsr_out,
             capture_out
	     );
   
   input    clk;
   input    rst_n;
   input    capture;
   
   output [15:0] lfsr_out;
   output [15:0] capture_out;

   integer 	N;

   reg 		feedback;
   reg [15:0]	lfsr;
   reg [15:0]	capture_out;
   reg [15:0] 	next_lfsr;
   reg [15:0] 	TAPS;

   // Taps for minimal length linear feedback shift register 16 (1,2,4,15)
   parameter TAPS_16 = 16'b1000_0000_0001_0110;

   assign #`DELTA lfsr_out = lfsr;
   
   // infer lfsr registers
   always @(posedge clk or negedge rst_n)
     begin: lfsr_reg
	if (!rst_n)
	  // can't reset to zero or PN generator won't work
	  lfsr <= 16'b0000_0000_0000_0001;
	else
          lfsr <= next_lfsr;
     end
   
   // infer capture registers
   always @(posedge clk or negedge rst_n)
     begin: capture_reg
	if (!rst_n)
	  // can't reset to zero or PN generator won't work
	  capture_out <= 16'b0000_0000_0000_0000;
	else if (capture)
	  capture_out <= lfsr;
	else
          capture_out <= capture_out;
     end

   // create the feedback logic
   always @(lfsr)
     begin: lfsr_feedback
	feedback = lfsr[15];
	TAPS = TAPS_16;

	for (N=15; N >= 1; N=N-1)
	  if (TAPS[N-1] == 1'b1)
	    next_lfsr[N] = lfsr[N-1] ^ feedback;
	  else
	    next_lfsr[N] = lfsr[N-1];
	next_lfsr[0] = feedback;
     end
   
endmodule

// cvff ba pnq
//
//$LOG$
//

